LiquidCache

Struct LiquidCache 

pub struct LiquidCache { /* private fields */ }
The main cache structure.

Implementations

Source

impl LiquidCache

pub fn compute_memory_usage_bytes(&self) -> u64

Get the memory usage of the cache in bytes.

pub fn write_stats( &self, parquet_file_path: impl AsRef<Path>, ) -> Result<(), ParquetError>

Write the stats of the cache to a parquet file.

Source

impl LiquidCache

pub fn new( batch_size: usize, max_cache_bytes: usize, cache_dir: PathBuf, cache_policy: Box<dyn CachePolicy>, squeeze_policy: Box<dyn SqueezePolicy>, io_mode: IoMode, ) -> Self

Create a new cache

pub fn register_or_get_file(&self, file_path: String) -> Arc<LiquidCachedFile>

Register a file in the cache.

pub fn batch_size(&self) -> usize

Get the batch size of the cache.

pub fn max_cache_bytes(&self) -> usize

Get the max cache bytes of the cache.

pub fn memory_usage_bytes(&self) -> usize

Get the memory usage of the cache in bytes.

pub fn disk_usage_bytes(&self) -> usize

Get the disk usage of the cache in bytes.

pub fn flush_trace(&self, to_file: impl AsRef<Path>)

Flush the cache trace to a file.

pub fn enable_trace(&self)

Enable the cache trace.

pub fn disable_trace(&self)

Disable the cache trace.

pub unsafe fn reset(&self)

Reset the cache.

Safety

This is unsafe because resetting the cache while other threads are using the cache may cause undefined behavior. You should only call this when no one else is using the cache.

pub fn flush_data(&self)

Flush all memory-based entries to disk while preserving their format. Arrow entries become DiskArrow, Liquid entries become DiskLiquid. Entries already on disk are left unchanged.

This is for admin use only. This has no guarantees that some new entry will not be inserted in the meantime, or some entries are promoted to memory again. You mostly want to use this when no one else is using the cache.

pub fn storage(&self) -> &Arc<CacheStorage>

Get the storage of the cache.