pub struct LiquidCachedRowGroup { /* private fields */ }Expand description
A row group in the cache.
Implementations
Sourceimpl LiquidCachedRowGroup
impl LiquidCachedRowGroup
Sourcepub fn create_column(
&self,
column_id: u64,
field: Arc<Field>,
) -> Arc<LiquidCachedColumn>
pub fn create_column( &self, column_id: u64, field: Arc<Field>, ) -> Arc<LiquidCachedColumn>
Create a column in the row group.
Sourcepub fn batch_size(&self) -> usize
pub fn batch_size(&self) -> usize
Returns the batch size configured for this cached row group.
Sourcepub fn get_column(&self, column_id: u64) -> Option<Arc<LiquidCachedColumn>>
pub fn get_column(&self, column_id: u64) -> Option<Arc<LiquidCachedColumn>>
Get a column from the row group.
Sourcepub fn get_column_by_name(
&self,
column_name: &str,
) -> Option<Arc<LiquidCachedColumn>>
pub fn get_column_by_name( &self, column_name: &str, ) -> Option<Arc<LiquidCachedColumn>>
Get a column from the row group by its field name.
Sourcepub async fn evaluate_selection_with_predicate(
&self,
batch_id: BatchID,
selection: &BooleanBuffer,
predicate: &mut LiquidPredicate,
) -> Option<Result<BooleanArray, ArrowError>>
pub async fn evaluate_selection_with_predicate( &self, batch_id: BatchID, selection: &BooleanBuffer, predicate: &mut LiquidPredicate, ) -> Option<Result<BooleanArray, ArrowError>>
Evaluate a predicate on a row group.